@@ -1,36 +1,32 @@
 package WiX3::XML::DirectoryRef;
 
-use 5.008003;
+use 5.008001;
 
 # Must be done before Moose, or it won't get picked up.
 use metaclass (
 	metaclass   => 'Moose::Meta::Class',
 	error_class => 'WiX3::Util::Error',
 );
-use Moose 2;
+use Moose;
 use Params::Util qw( _INSTANCE );
-use MooseX::Types::Moose qw( Int Str ArrayRef );
-use WiX3::XML::TagTypes qw( DirectoryRefChildTag DirectoryTag );
+use MooseX::Types::Moose qw( Int Str );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 with qw(WiX3::XML::Role::TagAllowsChildTags
   WiX3::Role::Traceable
 );
-
 ## Allows Component, Directory, Merge as children.
 
-has '+child_tags' => ( isa => ArrayRef [DirectoryRefChildTag] );
-
-
 #####################################################################
 # Accessors:
 #   None.
 
 has directory_object => (
 	is       => 'ro',
-	isa      => DirectoryTag,
+	isa      => 'WiX3::XML::Directory',
 	reader   => '_get_directory_object',
 	required => 1,
 	weak_ref => 1,
